package controller;

import domain.Person;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import repositories.PersonRepository;

import javax.validation.Valid;


@RestController
public class PersonController {

    private PersonRepository personRepository;

    @Autowired
    public PersonController(PersonRepository personRepository) {
        this.personRepository = personRepository;
    }

    @RequestMapping(value = "/people", method= RequestMethod.PUT)
    public ResponseEntity<Person> createPerson(@Valid @RequestBody Person p){
        personRepository.save(p);
        return new ResponseEntity<>(p, HttpStatus.CREATED);
    }

    @RequestMapping(value="/people/{id}", method=RequestMethod.GET)
    public ResponseEntity<Person> getPerson(@PathVariable int personId) {
        Person p = personRepository.findOne(personId);
        return new ResponseEntity<> (p, HttpStatus.OK);
    }

    @RequestMapping(value = "/people", method= RequestMethod.GET)
    public ResponseEntity<Iterable<Person>> getPersonList(){
        Iterable<Person> people = personRepository.findAll();
        return new ResponseEntity<>(people, HttpStatus.OK);
    }

    @RequestMapping(value = "people/{id}", method = RequestMethod.PUT)
    public ResponseEntity<Person> updatePerson(@Valid @RequestBody Person p){
        Person person = personRepository.save(p);
        return new ResponseEntity<>(person, HttpStatus.OK);
    }

    @RequestMapping(value = "/people", method = RequestMethod.DELETE)
    public void deletePerson(@PathVariable int id){
        personRepository.delete(id);
    }
}
